@@ -1,4 +1,7 @@
 
+"""
+The given file contains the class to refer to the tag entity
+"""
 from quartic_sdk.core.entities.base import Base
 import quartic_sdk.utilities.constants as Constants
 from quartic_sdk.core.iterators.tag_data_iterator import TagDataIterator
@@ -16,8 +19,13 @@ class Tag(Base):
         """
         return f"<{Constants.TAG_ENTITY}: {self.name}_{self.id}>"
 
-    def data(self, start_time, stop_time, granularity=0, return_type=Constants.RETURN_PANDAS,
-        transformations=[]):
+    def data(
+            self,
+            start_time,
+            stop_time,
+            granularity=0,
+            return_type=Constants.RETURN_PANDAS,
+            transformations=None):
         """
         Get the data for the given tag between the start_time and the stop_time
         for the given granularity
@@ -43,5 +51,13 @@ class Tag(Base):
             between the given duration
         """
         from quartic_sdk.core.entity_helpers.entity_list import EntityList
-        return TagDataIterator.create_tag_data_iterator(EntityList(Constants.TAG_ENTITY, [self]),
-            start_time, stop_time, self.api_helper, granularity, return_type, transformations)
+        return TagDataIterator.create_tag_data_iterator(
+            EntityList(
+                Constants.TAG_ENTITY,
+                [self]),
+            start_time,
+            stop_time,
+            self.api_helper,
+            granularity,
+            return_type,
+            transformations)
